==> qtcreator_4.2.0.orig.tar.xz: qt-creator-opensource-src-4.2.0/src/plugins/qmlprojectmanager/qmlprojectenvironmentaspect.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <projectexplorer/environmentaspect.h>

namespace QmlProjectManager {

class QmlProjectEnvironmentAspect : public ProjectExplorer::EnvironmentAspect
{
    Q_OBJECT

public:
    QmlProjectEnvironmentAspect(ProjectExplorer::RunConfiguration *rc);
    QmlProjectEnvironmentAspect *create(ProjectExplorer::RunConfiguration *parent) const;

    QList<int> possibleBaseEnvironments() const;
    QString baseEnvironmentDisplayName(int base) const;
    Utils::Environment baseEnvironment() const;

private:
    enum BaseEnvironmentBase {
        SystemEnvironmentBase = 0,
        KitEnvironmentBase
    };
};

} // namespace QmlProjectManager

==> qtcreator_4.5.2.orig.tar.xz: qt-creator-opensource-src-4.5.2/src/plugins/qmlprojectmanager/qmlprojectenvironmentaspect.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <projectexplorer/environmentaspect.h>

namespace QmlProjectManager {

class QmlProjectEnvironmentAspect : public ProjectExplorer::EnvironmentAspect
{
    Q_OBJECT

public:
    QmlProjectEnvironmentAspect(ProjectExplorer::RunConfiguration *rc);

    QList<int> possibleBaseEnvironments() const override;
    QString baseEnvironmentDisplayName(int base) const override;
    Utils::Environment baseEnvironment() const override;

private:
    enum BaseEnvironmentBase {
        SystemEnvironmentBase = 0,
        KitEnvironmentBase
    };
};

} // namespace QmlProjectManager
